Basler / Widgets
################

To facilitate the integration of the pypylon API in the different projects, we developped : 

* a *list system* to list available cameras, based on the *pypylon* API,
* a *driver* to setup and to access a camera, based on the *pypylon* API,
* a set of *widgets* based on *PyQt6*, to control and to display images.

This section deals with the **widgets**.

|

To use this widget, you can follow the steps mentionned in this section :ref:`PyQt6 integration <pyqt6_integration>`.

